#
# spec file for package ibus-chewing
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-chewing
Version:        2.0.0
Release:        1.2
Summary:        The Chewing engine for IBus input platform
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/definite/ibus-chewing
Source0:        https://github.com/definite/ibus-chewing/archive/%{version}/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake >= 2.6.2
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gob2
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(chewing)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(x11)

%description
The Chewing engine for IBus platform. It provides Chinese input method from
libchewing.
新酷音輸入法

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake -DLIBEXEC_DIR=%{_ibus_libexecdir}

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/doc/packages/ibus-chewing

%find_lang %{name} %{?no_lang_C}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc USER-GUIDE AUTHORS INSTALL ChangeLog-1.x CHANGELOG.md README.md
%license COPYING
%{_libexecdir}/ibus-*
%{_datadir}/%{name}
%{_datadir}/ibus
%{_datadir}/applications/ibus-setup-chewing.desktop
%{_datadir}/glib-2.0/schemas/org.freedesktop.IBus.Chewing.gschema.xml

%changelog
* Sun Apr 28 2024 jun wang <jgwang@suse.com>
- Update to version 2.0.0
  * Add: On non-gnome desktop with systray icon enabled, IBus will
    display the currently selected input mode. Clicking on
    the icon shows a menu to switch input modes.
  * Changed:
  - IBus-Chewing Preferences has been rewritten in GTK4 and
    libadwaita
  - Removed GOB2 dependency. Now gobjects are written in plain
    C99
  - Removed cmake-fedora dependency. Now CMakeLists.txt only
    depends on built-in modules
  - New CMake presets can be used for building with different
    configurations
  - Refresh property list (language bar)
  - Update IBusChewingLookupTable.c
  - Update property list (language bar)
  - Update pre-edit and aux text after commit_text ()
  - Change UTF8_MAX_BYTES from 6 to 4
  - Fix self->bpmfLen always = 0
  - Update keyHandlingRules
  - Destroy *preEditText, *auxText and *outgoingText when disable
  - Port to GTK+-3
  - Ignore keystrokes in English mode
  - Add: use arrow keys to choose candidate
  - Display page number of the lookup table
  - Show cursor on lookup table
  - Stop marking interval with double underline
  - Support vertical lookup table and optimize turn page keys
  - Tweak ibus-setup dialog window and replace some deprecated
    APIs
  - Add dropdown menu for Chi-Eng-Mode toggle key
  - Update ChangeLog and RELEASE-NOTES
  * Deprecated: X11 support has been deprecated. IBus-chewing no
    longer requires X11 to build. Running in X11
    environment will continue to work as long as IBus
    still supports X11/XIM
  * Removed:
  - GtkStatusIcon (X11) based systray icon has been removed. Now
    there is only one icon provided by IBus to avoid confusion.
    The new systray does not support using left mouse button to
    switch between Chinese and English, and the right button to
    switch between full and half width mode. (#190)
  - Sync IM status back to CapsLock has been removed which also
    depends on X11
  * Fixed:
  - Modifier key handling has been improved. Super key will no
    longer conflict with desktop shortcut handling
  - Shift key handling in English mode has been improved. Now
    Shift+Arrow key will work correctly for highlighting text or
    scroll window
  - Shift_L or Shift_R can be individually asssigned as Eng/Chi
    toggle key
- Drop ibus-chewing-drop-cmake-fedora.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Jan 20 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Fri Dec 20 2019 Cliff Zhao <qzhao@suse.com>
- Add ibus-chewing-drop-cmake-fedora.patch: Backport previous cmake
  module to get rid of dependence of cmake-fedora-modules, and
  switch to depends on cmake upstream 2.6.2.
* Fri Nov  8 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.6.1
  * Fixed RHBZ#1411189 - ibus-engine-chewing killed by SIGSEGV when receiving
    KP_Insert
  * Update cmake-fedora to 2.9.3
  * Fixed pre-commit so it does not chop directory
  * GitHub Issue: #35 Support KB_THL_PINYIN and KB_MPS2_PINYIN
    RHBZ: #1182819: - RFE: Support KB_THL_PINYIN and KB_MPS2_PINYIN
  * Fixed GitHub Issue: #51 Hard-coded path in data/ibus-setup-chewing.desktop
  * Fixed GitHub Issue: #85 Adding phrase using Ctrl * Num failed to respond
  * Fixed GitHub Issue: #93 Remove XTST from CMakeLists.txt
- Use cmake-fedora in system default
-Mon Oct  7 14:55:04 UTC 2019 - Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.1
  * Fix:
    + GH issue #73: Ctrl, Alt, Ins causes the pre-edit duplicate commit
    + GH issue #74: Failed to clean the PreEdit when changing input focus
    + GH issue #79: Failed to input space when "space-as-selection"
    + GH issue #87 Modify dropdown menu for selecting keys
    + GH issue #88 Numpad should be able to select
    + RHBZ #1337185 - Cannot add phrases with Ctrl
    A.k.a GH issue #63
    Thank for contribution from hiunnhue
  * Acknowledge:
    + Obata Akio contributed pull request 71, 72, 73
    + hiunnhue contributed pull request 75, 76, 77, 78, 80, 81, 82, 83, 84, 86,
    87, 90, 91, 92, 94
    + hiunnhue fixed issue 73, 74, 79, 87, 88, 90, 91, 92, 94
  * Fixed the issues found in static checks
  * Fixed Bug 1182813 ibus-chewing crashes gedit in search box while window out
    of focus
    a.k.a GitHub issue #28
  * Fixed GitHub issue #37 Cannot use cmake out of source build Cannot use cmake
    out of source build
  * Fixed GitHub issue #47 CHEWING_DATADIR CMake variable name mismatch
  * Fixed GitHub issue #61 GConf2 should be removed from INSTALL document
  * Fixed GitHub issue #64 systray should be able to show the Chinese/English
    mode
  * Fixed GitHub issue #68 CPU usage very high when switch to Chewing Engine
  * Fixed Bug 1177198 - [abrt] ibus-chewing: XGetKeyboardControl():
    ibus-engine-chewing killed by SIGSEGV
  * Fixed Bug 1319403 - [RFE] ibus-chewing: New option: Caps Lock behavior
    a.k.a. GitHub issue #66
  * Fixed Bug 1330194 - Ctrl-c failed to output as Ctrl-c
    a.k.a. GitHub issue #69
  * Pull Request #67 Fix property "easy-symbol-input" is covered by
    "shift-toggle-chinese"
    Thanks southernbear for providing this fix.
* Fri Mar  2 2018 crrodriguez@opensuse.org
- Change xorg-x11-devel --> pkgconfig(x11)
- Explicitly buildrequire glib components and gtk x11, not just
  gtk2-devel
* Tue Oct 20 2015 i@marguerite.su
- update version 1.4.14
  * Fixed the issues found in static checks
- changes in 1.14.11.1
  * Resolves Bug 1013977 - Slow focus change with ibus-chewing
  * Resolves Bug 1062133 - ibus-chewing may not handle key event
    after focus change
  * Resolves Bug 1073797 - Cannot identify input mode for Chinese
    IME (ibus-chewing)
  * Fixed Bug 902866 - ibus-chewing uses dconf but still installs
    gconf schemas
  * MakerDialog GUI is only loaded when setting dialog is invoked.
  * Setting is removed from ibus-properties because it can be launched
    from either:
    + Executable ibus-setup-chewing: Usually under /usr/libexec
    + Input method preference in IBus preference.
  * Fixed github issue #43: First space not able to input
  * Fixed github issue #44: Update input-events (for libchewing-0.4.0)
  * Fixed github issue #45: Optimize properties handling.
- remove explicit Requires on libchewing > 0.3.2, ldconfig will
  do the work
- drop patch: ibus-chewing-fix-license.patch, upstream fixed
- dont build with gconf support, such codes are buggy
* Wed Aug 13 2014 fcrozat@suse.com
- Add provides locale(zh_TW)
* Wed Jul  2 2014 fcrozat@suse.com
- Add ibus-chewing-fix-license.patch: fix incorrect license on one
  header.
* Sat Mar  1 2014 hillwood@linuxfans.org
- Update to 1.4.10.1
  1.4.7 to 1.4.10.1:
  * Resolves Bug 1054937 - Broken %%defattr in ibus-chewing
  1.4.6 to 1.4.7:
  * Target "translation" is built separately with all, in order to
    tame multiple job make.
  1.4.5 to 1.4.6:
  * Fixed Build for RHEL7
  1.4.4 to 1.4.5:
  * Resolves Bug 1013977 - ibus-chewing needs to have ibus write-cache
  - -system in %%post and %%postun
  * Resolves Bug 1027031 - CVE-2013-4509 ibus-chewing: ibus: visible
    password entry flaw [rhel-7.0]
  * Resolves Bug 1028911 - [zh_TW]'Chinese<->English' switch does not work
    when clicking on the Chewing menu list.
  * Resolves Bug 1045868 - ibus-chewing *again* not built with $RPM_OPT_FLAGS
  * Option "Sync between caps lock and IM":
    + Default of  is changed to "disable",  because the previous default
    "keyboard" cause bug 1028911 for GNOME Shell.
    + Now Sync from "input method" can control Caps LED in GNOME shell.
  * Translation added: de_DE, es_ES, it_IT, pt_BR, uk_UA
  * Set environment IBUS_CHEWING_LOGFILE for ibus-chewing log.
* Thu Dec 19 2013 ftake@geeko.jp
- Update to 1.4.4
  * Fixed IBus issue 1294: Chewing GUI in French [patch]
  * Fixed bogus date
  * Fixed password is visible on GNOME lock screen
    (bnc#847718, CVE-2013-4509)
  * Fixed ibus-chewing 1.4.3-1 not built with (rh#842856)
- Drop cmake-fedora-modules.tar.bz2
  * the source archive includes a newer version of cmake-fedora
* Tue Dec 18 2012 swyear@gmail.com
- Update to 1.4.3
- Fixed GitHub issue #30: Rework decorate_preedit
  by merging pull request #30 from buganini
- Fixed GitHub issue #31: Properly refresh property
  by merging pull request #31 from buganini
* Sat Aug 25 2012 swyear@gmail.com
- Update to 1.4.2
- Fixed GitHub issue #7: highlighted text be cut after switch back to pure ibus
  by merging pull request #24 from buganini
- Fixed GitHub issue #20: Shift key will send duplicated strings
  by merging pull request #22 from buganini
- Fixed GitHub issue #21: somethings wrong with cmake
- Fixed GitHub issue #25: Weird symbol when input with somethings highlighted
  by merging pull request #26 from buganini
- Fixed GitHub issue #27: Local path committed into tree
- Fixed: Bug 713033 -  [zh_TW] ibus-chewing problem
- Fixed: Bug 745371 -  ibus-chewing: mode confusion In Temporary English mode and Chinese mode later on
- Fixed: Google Issue 1172: [ibus-chewing] move elf file to standard directory.
- Fixed: Google Issue 1426: ibus-chewing-1.3.10 installs directory /gconf to root filesystem
- Fixed: Google Issue 1428: ibus-chewing-1.3.10 fails to save it's settings
- Fixed: Google Issue 1481: Some characters are missing when a long string in preedit buffer.
- Fixed: Google Issue 1490: Cannot change INSTAL prefix for ibus-chewing-1.4.0
* Thu Aug 23 2012 swyear@gmail.com
- Update to 1.4.0
- fix issue http://code.google.com/p/ibus/issues/detail?id=1481
* Sun Jun 24 2012 swyear@gmail.com
- Add patch from http://code.google.com/p/ibus/issues/detail?id=1428
  Fix ibus-chewing module's setting can not be saved
* Fri Jun  8 2012 swyear@gmail.com
- remove "Provides: locale(ibus:zh_TW;zh_HK)"
* Tue Mar 20 2012 swyear@gmail.com
- Fix ibus-chewing build fail for ibus-1.4.1
  https://bugs.gentoo.org/show_bug.cgi?id=407695
* Mon Oct 17 2011 swyear@gmail.com
- Update to 1.3.10
- Need cmake-fedora-modules (stated in CMakeList.txt),add to source
- upstream changelog:
- Fixed Bug 726335 (Google issue 1281)- [abrt] ibus-chewing-1.3.9.2-3.fc15: g_atomic_int_get:
  Process /usr/libexec/ibus-engine-chewing was killed by signal 11 (SIGSEGV) using patch from Scott Tsai
- Fixed Bug 727018 - ibus compose file needs a symbol tag for gnome-shell
- Fixed characters duplication problem (Google issue 1245, GitHub ibus-chewing issue 2)
- Fixed KP-Enter not been able to commit preedit buffer. (Google issue 1303, GitHub ibus-chewing issue 4)
- Depends on cmake-fedora now.
- Fixed issue 1274, which is addressed by yusake's comments on d9009bf.
- Add compile flag for GNOME3.
- Add command line option: showFlags
- ibus-gnome special symbol
- Thanks Fred Chien's patch against that candidate window cannot be closed
  with escape key since selected tone.
- Thanks Fourdollar's patch for Fix plain zhuyin with space as selection problem.
- Remove support for ibus-1.2 and prior.
* Mon Jul 25 2011 tiwai@suse.de
- Fix builds with older distros
- Minor spec file cleanup
* Mon Jul 25 2011 tiwai@suse.de
- Don't remove buildroot in install, use make_install macro
* Fri Jul 22 2011 tiwai@suse.de
- Add locale-specific provides tag (bnc#707712)
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.3.9.2
* Fri Apr 23 2010 tiwai@suse.de
- fix filelist
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
